@@ -1,17 +1,11 @@
 package Class::MOP::Mixin::AttributeCore;
-BEGIN {
-  $Class::MOP::Mixin::AttributeCore::AUTHORITY = 'cpan:STEVAN';
-}
-{
-  $Class::MOP::Mixin::AttributeCore::VERSION = '2.1005';
-}
-
+$Class::MOP::Mixin::AttributeCore::VERSION = '2.1213';
 use strict;
 use warnings;
 
 use Scalar::Util 'blessed';
 
-use base 'Class::MOP::Mixin';
+use parent 'Class::MOP::Mixin';
 
 sub has_accessor        { defined $_[0]->{'accessor'} }
 sub has_reader          { defined $_[0]->{'reader'} }
@@ -59,26 +53,70 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Class::MOP::Mixin::AttributeCore - Core attributes shared by attribute metaclasses
 
 =head1 VERSION
 
-version 2.1005
+version 2.1213
 
 =head1 DESCRIPTION
 
 This class implements the core attributes (aka properties) shared by all
 attributes. See the L<Class::MOP::Attribute> documentation for API details.
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Moose is maintained by the Moose Cabal, along with the help of many contributors. See L<Moose/CABAL> and L<Moose/CONTRIBUTORS> for details.
+=over 4
+
+=item *
+
+Stevan Little <stevan.little@iinteractive.com>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=item *
+
+Jesse Luehrs <doy@tozt.net>
+
+=item *
+
+Shawn M Moore <code@sartak.org>
+
+=item *
+
+יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Florian Ragwitz <rafl@debian.org>
+
+=item *
+
+Hans Dieter Pearcey <hdp@weftsoar.net>
+
+=item *
+
+Chris Prather <chris@prather.org>
+
+=item *
+
+Matt S Trout <mst@shadowcat.co.uk>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Infinity Interactive, Inc..
+This software is copyright (c) 2006 by Infinity Interactive, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
