@@ -1,18 +1,15 @@
-package Moose;
-BEGIN {
-  $Moose::AUTHORITY = 'cpan:STEVAN';
-}
-{
-  $Moose::VERSION = '2.1005';
-}
 use strict;
 use warnings;
+package Moose;
+$Moose::VERSION = '2.1213';
+$Moose::AUTHORITY = 'cpan:STEVAN';
 
-use 5.008;
+use 5.008003;
 
 use Scalar::Util 'blessed';
 use Carp         'carp', 'confess';
-use Class::Load  'is_class_loaded';
+use Module::Runtime 'module_notional_filename';
+use Class::Load  'is_class_loaded', 'load_class';
 
 use Moose::Deprecated;
 use Moose::Exporter;
@@ -41,21 +38,17 @@ use Moose::Meta::Role::Application::ToRole;
 use Moose::Meta::Role::Application::ToInstance;
 
 use Moose::Util::TypeConstraints;
-use Moose::Util ();
+use Moose::Util 'throw_exception';
 
 use Moose::Meta::Attribute::Native;
 
-sub throw_error {
-    # FIXME This
-    shift;
-    goto \&confess
-}
-
 sub extends {
     my $meta = shift;
 
-    Moose->throw_error("Must derive at least one class") unless @_;
-
+    unless ( @_ )
+    {
+        throw_exception( ExtendsMissingArgs => class_name => $meta->name );
+    }
     # this checks the metaclass to make sure
     # it is correct, sometimes it can get out
     # of sync when the classes are being built
@@ -66,19 +59,21 @@ sub with {
     Moose::Util::apply_all_roles(shift, @_);
 }
 
+sub throw_error {
+    shift;
+    Class::MOP::Object->throw_error(@_);
+}
+
 sub has {
     my $meta = shift;
     my $name = shift;
 
-    Moose->throw_error('Usage: has \'name\' => ( key => value, ... )')
-        if @_ % 2 == 1;
-
     my %context = Moose::Util::_caller_info;
     $context{context} = 'has declaration';
     $context{type} = 'class';
-    my %options = ( definition_context => \%context, @_ );
+    my @options = ( definition_context => \%context, @_ );
     my $attrs = ( ref($name) eq 'ARRAY' ) ? $name : [ ($name) ];
-    $meta->add_attribute( $_, %options ) for @$attrs;
+    $meta->add_attribute( $_, @options ) for @$attrs;
 }
 
 sub before {
@@ -150,15 +145,16 @@ sub init_meta {
     my %args = @_;
 
     my $class = $args{for_class}
-        or Moose->throw_error("Cannot call init_meta without specifying a for_class");
+        or throw_exception( InitMetaRequiresClass => params => \%args );
+
     my $base_class = $args{base_class} || 'Moose::Object';
     my $metaclass  = $args{metaclass}  || 'Moose::Meta::Class';
     my $meta_name  = exists $args{meta_name} ? $args{meta_name} : 'meta';
 
-    Moose->throw_error("The Metaclass $metaclass must be loaded. (Perhaps you forgot to 'use $metaclass'?)")
+    throw_exception( MetaclassNotLoaded => class_name => $metaclass )
         unless is_class_loaded($metaclass);
 
-    Moose->throw_error("The Metaclass $metaclass must be a subclass of Moose::Meta::Class.")
+    throw_exception( MetaclassMustBeASubclassOfMooseMetaClass => class_name => $metaclass )
         unless $metaclass->isa('Moose::Meta::Class');
 
     # make a subtype for each Moose class
@@ -169,11 +165,16 @@ sub init_meta {
 
     if ( $meta = Class::MOP::get_metaclass_by_name($class) ) {
         unless ( $meta->isa("Moose::Meta::Class") ) {
-            my $error_message = "$class already has a metaclass, but it does not inherit $metaclass ($meta).";
             if ( $meta->isa('Moose::Meta::Role') ) {
-                Moose->throw_error($error_message . ' You cannot make the same thing a role and a class. Remove either Moose or Moose::Role.');
+                throw_exception( MetaclassIsARoleNotASubclassOfGivenMetaclass => role_name => $class,
+                                                                                 metaclass => $metaclass,
+                                                                                 role      => $meta
+                               );
             } else {
-                Moose->throw_error($error_message);
+                throw_exception( MetaclassIsNotASubclassOfGivenMetaclass => class_name => $class,
+                                                                            metaclass  => $metaclass,
+                                                                            class      => $meta
+                               );
             }
         }
     } else {
@@ -200,6 +201,9 @@ sub init_meta {
         }
 
         $meta = $metaclass->initialize($class);
+        my $filename = module_notional_filename($meta->name);
+        $INC{$filename} = '(set by Moose)'
+            unless exists $INC{$filename};
     }
 
     if (defined $meta_name) {
@@ -288,13 +292,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Moose - A postmodern object system for Perl 5
 
 =head1 VERSION
 
-version 2.1005
+version 2.1213
 
 =head1 SYNOPSIS
 
@@ -350,7 +356,7 @@ features which interest you.
 
 The C<MooseX::> namespace is the official place to find Moose extensions.
 These extensions can be found on the CPAN.  The easiest way to find them
-is to search for them (L<http://search.cpan.org/search?query=MooseX::>),
+is to search for them (L<https://metacpan.org/search?q=MooseX::>),
 or to examine L<Task::Moose> which aims to keep an up-to-date, easily
 installable list of Moose extensions.
 
@@ -412,8 +418,8 @@ on the current class.
 This function will set the superclass(es) for the current class. If the parent
 classes are not yet loaded, then C<extends> tries to load them.
 
-This approach is recommended instead of C<use base>, because C<use base>
-actually C<push>es onto the class's C<@ISA>, whereas C<extends> will
+This approach is recommended instead of C<use L<base>>/C<use L<parent>>, because
+C<use base> actually C<push>es onto the class's C<@ISA>, whereas C<extends> will
 replace it. This is important to ensure that classes which do not have
 superclasses still properly inherit from L<Moose::Object>.
 
@@ -908,11 +914,11 @@ respectively.
 
 Metaclass compatibility is a thorny subject. You should start by
 reading the "About Metaclass compatibility" section in the
-C<Class::MOP> docs.
+L<Class::MOP> docs.
 
 Moose will attempt to resolve a few cases of metaclass incompatibility
 when you set the superclasses for a class, in addition to the cases that
-C<Class::MOP> handles.
+L<Class::MOP> handles.
 
 Moose tries to determine if the metaclasses only "differ by roles". This
 means that the parent and child's metaclass share a common ancestor in
@@ -988,6 +994,10 @@ are a few of our favorites. Feel free to contribute more!
 
 =item * Meta Object Orientation Syntax Extensions
 
+=item * Moo, Only Overengineered, Slow, and Execrable (blame rjbs!)
+
+=item * Massive Object-Oriented Stacktrace Emitter
+
 =back
 
 =head1 ACKNOWLEDGEMENTS
@@ -1015,7 +1025,7 @@ early ideas/feature-requests/encouragement/bug-finding.
 
 =over 4
 
-=item L<http://www.iinteractive.com/moose>
+=item L<http://moose.perl.org/>
 
 This is the official web home of Moose. It contains links to our public git
 repository, as well as links to a number of talks and articles on Moose and
@@ -1039,7 +1049,7 @@ Part 2 - L<http://www.stonehenge.com/merlyn/LinuxMag/col95.html>
 
 =item Several Moose extension modules in the C<MooseX::> namespace.
 
-See L<http://search.cpan.org/search?query=MooseX::> for extensions.
+See L<https://metacpan.org/search?q=MooseX::> for extensions.
 
 =back
 
@@ -1072,7 +1082,8 @@ All complex software has bugs lurking in it, and this module is no
 exception.
 
 Please report any bugs to C<bug-moose@rt.cpan.org>, or through the web
-interface at L<http://rt.cpan.org>.
+interface at L<http://rt.cpan.org>. You can also submit a C<TODO> test as a
+pull request at L<https://github.com/moose/Moose>.
 
 You can also discuss feature requests or possible bugs on the Moose mailing
 list (moose@perl.org) or on IRC at L<irc://irc.perl.org/#moose>.
@@ -1096,25 +1107,7 @@ can contribute.
 There are only a few people with the rights to release a new version
 of Moose. The Moose Cabal are the people to go to with questions regarding
 the wider purview of Moose. They help maintain not just the code
-but the community as well.
-
-Stevan (stevan) Little E<lt>stevan@iinteractive.comE<gt>
-
-Jesse (doy) Luehrs E<lt>doy at tozt dot netE<gt>
-
-Yuval (nothingmuch) Kogman
-
-Shawn (sartak) Moore E<lt>sartak@bestpractical.comE<gt>
-
-Hans Dieter (confound) Pearcey E<lt>hdp@pobox.comE<gt>
-
-Chris (perigrin) Prather
-
-Florian Ragwitz E<lt>rafl@debian.orgE<gt>
-
-Dave (autarch) Rolsky E<lt>autarch@urth.orgE<gt>
-
-Karen (ether) Etheridge E<lt>ether@cpan.orgE<gt>
+but the community as well. See the list below under C<AUTHORS>.
 
 =head1 CONTRIBUTORS
 
@@ -1216,13 +1209,55 @@ Wallace (wreis) Reis
 
 ... and many other #moose folks
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Moose is maintained by the Moose Cabal, along with the help of many contributors. See L<Moose/CABAL> and L<Moose/CONTRIBUTORS> for details.
+=over 4
+
+=item *
+
+Stevan Little <stevan.little@iinteractive.com>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=item *
+
+Jesse Luehrs <doy@tozt.net>
+
+=item *
+
+Shawn M Moore <code@sartak.org>
+
+=item *
+
+יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Florian Ragwitz <rafl@debian.org>
+
+=item *
+
+Hans Dieter Pearcey <hdp@weftsoar.net>
+
+=item *
+
+Chris Prather <chris@prather.org>
+
+=item *
+
+Matt S Trout <mst@shadowcat.co.uk>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Infinity Interactive, Inc..
+This software is copyright (c) 2006 by Infinity Interactive, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
