@@ -1,11 +1,5 @@
 package Moose::Exporter;
-BEGIN {
-  $Moose::Exporter::AUTHORITY = 'cpan:STEVAN';
-}
-{
-  $Moose::Exporter::VERSION = '2.1005';
-}
-
+$Moose::Exporter::VERSION = '2.1213';
 use strict;
 use warnings;
 
@@ -13,10 +7,12 @@ use Class::Load qw(is_class_loaded);
 use Class::MOP;
 use List::MoreUtils qw( first_index uniq );
 use Moose::Util::MetaRole;
-use Scalar::Util qw(reftype);
+use Scalar::Util 1.11 qw(reftype);
 use Sub::Exporter 0.980;
 use Sub::Name qw(subname);
 
+use Moose::Util 'throw_exception';
+
 my %EXPORT_SPEC;
 
 sub setup_import_methods {
@@ -87,10 +83,16 @@ sub build_import_methods {
     my $package = Class::MOP::Package->initialize($exporting_package);
     for my $to_install ( @{ $args{install} || [] } ) {
         my $symbol = '&' . $to_install;
+
         next
             unless $methods{$to_install}
                 && !$package->has_package_symbol($symbol);
-        $package->add_package_symbol( $symbol, $methods{$to_install} );
+        $package->add_package_symbol(
+            $symbol,
+            subname(
+                $exporting_package . '::' . $to_install, $methods{$to_install}
+            )
+        );
     }
 
     return ( $methods{import}, $methods{unimport}, $methods{init_meta} );
@@ -161,9 +163,9 @@ sub _also_list_for_package {
     if ( !exists $EXPORT_SPEC{$package} ) {
         my $loaded = is_class_loaded($package);
 
-        die "Package in also ($package) does not seem to "
-            . "use Moose::Exporter"
-            . ( $loaded ? "" : " (is it loaded?)" );
+        throw_exception( PackageDoesNotUseMooseExporter => package   => $package,
+                                                           is_loaded => $loaded
+                       );
     }
 
     my $also = $EXPORT_SPEC{$package}{also};
@@ -192,12 +194,9 @@ sub _die_if_also_list_cycles_back_to_existing_stack {
         for my $stack_member (@$existing_stack) {
             next unless $also_member eq $stack_member;
 
-            die
-                "Circular reference in 'also' parameter to Moose::Exporter between "
-                . join(
-                ', ',
-                @$existing_stack
-                ) . " and $also_member";
+            throw_exception( CircularReferenceInAlso => also_parameter => $also_member,
+                                                        stack          => $existing_stack
+                           );
         }
 
         _die_if_also_list_cycles_back_to_existing_stack(
@@ -216,10 +215,10 @@ sub _parse_trait_aliases {
         my $name;
         if (ref($alias)) {
             reftype($alias) eq 'ARRAY'
-                or Moose->throw_error(reftype($alias) . " references are not "
-                                    . "valid arguments to the 'trait_aliases' "
-                                    . "option");
-
+                or throw_exception( InvalidArgumentsToTraitAliases => class_name   => $class,
+                                                                      package_name => $package,
+                                                                      alias        => $alias
+                                  );
             ($alias, $name) = @$alias;
         }
         else {
@@ -500,10 +499,9 @@ sub _make_import_sub {
             _apply_meta_traits( $CALLER, $traits, $meta_lookup );
         }
         elsif ( @{$traits} ) {
-            require Moose;
-            Moose->throw_error(
-                "Cannot provide traits when $class does not have an init_meta() method"
-            );
+            throw_exception( ClassDoesNotHaveInitMeta => class_name => $class,
+                                                         traits     => $traits
+                           );
         }
 
         my ( undef, @args ) = @_;
@@ -650,9 +648,9 @@ sub _apply_meta_traits {
 
     my $type = $meta->isa('Moose::Meta::Role') ? 'Role'
              : $meta->isa('Class::MOP::Class') ? 'Class'
-             : Moose->throw_error('Cannot determine metaclass type for '
-                                . 'trait application. Meta isa '
-                                . ref $meta);
+             : confess('Cannot determine metaclass type for '
+                           . 'trait application. Meta isa '
+                           . ref $meta);
 
     my @resolved_traits = map {
         ref $_
@@ -791,13 +789,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Moose::Exporter - make an import() and unimport() just like Moose.pm
 
 =head1 VERSION
 
-version 2.1005
+version 2.1213
 
 =head1 SYNOPSIS
 
@@ -861,8 +861,8 @@ C<unimport> methods for your module. The C<import> method
 will export the functions you specify, and can also re-export functions
 exported by some other module (like C<Moose.pm>). If you pass any parameters
 for L<Moose::Util::MetaRole>, the C<import> method will also call
-C<Moose::Util::MetaRole::apply_metaroles> and
-C<Moose::Util::MetaRole::apply_base_class_roles> as needed, after making
+L<Moose::Util::MetaRole::apply_metaroles|Moose::Util::MetaRole/apply_metaroles> and
+L<Moose::Util::MetaRole::apply_base_class_roles|Moose::Util::MetaRole/apply_base_class_roles> as needed, after making
 sure the metaclass is initialized.
 
 The C<unimport> method cleans the caller's namespace of all the exported
@@ -936,13 +936,14 @@ Accordingly, this function is expected to return a metaclass.
 
 =back
 
-You can also provide parameters for C<Moose::Util::MetaRole::apply_metaroles>
-and C<Moose::Util::MetaRole::base_class_roles>. Specifically, valid parameters
+You can also provide parameters for L<Moose::Util::MetaRole::apply_metaroles|Moose::Util::MetaRole/apply_metaroles>
+and L<Moose::Util::MetaRole::apply_base_class_roles|Moose::Util::MetaRole/apply_base_class_roles>. Specifically, valid parameters
 are "class_metaroles", "role_metaroles", and "base_class_roles".
 
 =item B<< Moose::Exporter->build_import_methods(...) >>
 
-Returns two code refs, one for C<import> and one for C<unimport>.
+Returns three code refs, one for C<import>, one for C<unimport> and one for
+C<init_meta>.
 
 Accepts the additional C<install> option, which accepts an arrayref of method
 names to install into your exporting package. The valid options are C<import>
@@ -995,13 +996,55 @@ a metaclass for the caller is an error.
 
 See L<Moose/BUGS> for details on reporting bugs.
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Moose is maintained by the Moose Cabal, along with the help of many contributors. See L<Moose/CABAL> and L<Moose/CONTRIBUTORS> for details.
+=over 4
+
+=item *
+
+Stevan Little <stevan.little@iinteractive.com>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=item *
+
+Jesse Luehrs <doy@tozt.net>
+
+=item *
+
+Shawn M Moore <code@sartak.org>
+
+=item *
+
+יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Florian Ragwitz <rafl@debian.org>
+
+=item *
+
+Hans Dieter Pearcey <hdp@weftsoar.net>
+
+=item *
+
+Chris Prather <chris@prather.org>
+
+=item *
+
+Matt S Trout <mst@shadowcat.co.uk>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Infinity Interactive, Inc..
+This software is copyright (c) 2006 by Infinity Interactive, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
