@@ -1,18 +1,14 @@
 package Moose::Meta::Class::Immutable::Trait;
-BEGIN {
-  $Moose::Meta::Class::Immutable::Trait::AUTHORITY = 'cpan:STEVAN';
-}
-{
-  $Moose::Meta::Class::Immutable::Trait::VERSION = '2.1005';
-}
-
+$Moose::Meta::Class::Immutable::Trait::VERSION = '2.1213';
 use strict;
 use warnings;
 
 use Class::MOP;
 use Scalar::Util qw( blessed );
 
-use base 'Class::MOP::Class::Immutable::Trait';
+use parent 'Class::MOP::Class::Immutable::Trait';
+
+use Moose::Util 'throw_exception';
 
 sub add_role { $_[1]->_immutable_cannot_call }
 
@@ -34,7 +30,7 @@ sub does_role {
     my $role = shift;
 
     (defined $role)
-        || $self->throw_error("You must supply a role name to look for");
+        || throw_exception( RoleNameRequired => class_name => $self->name );
 
     $self->{__immutable}{does_role} ||= { map { $_->name => 1 } $self->calculate_all_roles_with_inheritance };
 
@@ -51,13 +47,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Moose::Meta::Class::Immutable::Trait - Implements immutability for metaclass objects
 
 =head1 VERSION
 
-version 2.1005
+version 2.1213
 
 =head1 DESCRIPTION
 
@@ -68,13 +66,55 @@ is deep guts.
 
 See L<Moose/BUGS> for details on reporting bugs.
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Moose is maintained by the Moose Cabal, along with the help of many contributors. See L<Moose/CABAL> and L<Moose/CONTRIBUTORS> for details.
+=over 4
+
+=item *
+
+Stevan Little <stevan.little@iinteractive.com>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=item *
+
+Jesse Luehrs <doy@tozt.net>
+
+=item *
+
+Shawn M Moore <code@sartak.org>
+
+=item *
+
+יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Florian Ragwitz <rafl@debian.org>
+
+=item *
+
+Hans Dieter Pearcey <hdp@weftsoar.net>
+
+=item *
+
+Chris Prather <chris@prather.org>
+
+=item *
+
+Matt S Trout <mst@shadowcat.co.uk>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Infinity Interactive, Inc..
+This software is copyright (c) 2006 by Infinity Interactive, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
