@@ -1,20 +1,15 @@
-
 package Moose::Meta::Method::Accessor;
-BEGIN {
-  $Moose::Meta::Method::Accessor::AUTHORITY = 'cpan:STEVAN';
-}
-{
-  $Moose::Meta::Method::Accessor::VERSION = '2.1005';
-}
-
+$Moose::Meta::Method::Accessor::VERSION = '2.1213';
 use strict;
 use warnings;
 
 use Try::Tiny;
 
-use base 'Moose::Meta::Method',
+use parent 'Moose::Meta::Method',
          'Class::MOP::Method::Accessor';
 
+use Moose::Util 'throw_exception';
+
 # multiple inheritance is terrible
 sub new {
     goto &Class::MOP::Method::Accessor::new;
@@ -38,12 +33,10 @@ sub _compile_code {
         $self->SUPER::_compile_code(@args);
     }
     catch {
-        $self->throw_error(
-            'Could not create writer for '
-          . "'" . $self->associated_attribute->name . "' "
-          . 'because ' . $_,
-            error => $_,
-        );
+        throw_exception( CouldNotCreateWriter => attribute      => $self->associated_attribute,
+                                                 error          => $_,
+                                                 instance       => $self
+                       );
     };
 }
 
@@ -135,13 +128,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Moose::Meta::Method::Accessor - A Moose Method metaclass for accessors
 
 =head1 VERSION
 
-version 2.1005
+version 2.1213
 
 =head1 DESCRIPTION
 
@@ -156,13 +151,55 @@ L<Class::MOP::Method::Accessor> documentation.
 
 See L<Moose/BUGS> for details on reporting bugs.
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Moose is maintained by the Moose Cabal, along with the help of many contributors. See L<Moose/CABAL> and L<Moose/CONTRIBUTORS> for details.
+=over 4
+
+=item *
+
+Stevan Little <stevan.little@iinteractive.com>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=item *
+
+Jesse Luehrs <doy@tozt.net>
+
+=item *
+
+Shawn M Moore <code@sartak.org>
+
+=item *
+
+יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Florian Ragwitz <rafl@debian.org>
+
+=item *
+
+Hans Dieter Pearcey <hdp@weftsoar.net>
+
+=item *
+
+Chris Prather <chris@prather.org>
+
+=item *
+
+Matt S Trout <mst@shadowcat.co.uk>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Infinity Interactive, Inc..
+This software is copyright (c) 2006 by Infinity Interactive, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
