@@ -1,11 +1,5 @@
 package Moose::Meta::Method::Accessor::Native::Array::first;
-BEGIN {
-  $Moose::Meta::Method::Accessor::Native::Array::first::AUTHORITY = 'cpan:STEVAN';
-}
-{
-  $Moose::Meta::Method::Accessor::Native::Array::first::VERSION = '2.0402';
-}
-
+$Moose::Meta::Method::Accessor::Native::Array::first::VERSION = '2.1213';
 use strict;
 use warnings;
 
@@ -14,15 +8,7 @@ use Params::Util ();
 
 use Moose::Role;
 
-with 'Moose::Meta::Method::Accessor::Native::Reader' => {
-    -excludes => [
-        qw(
-            _minimum_arguments
-            _maximum_arguments
-            _inline_check_arguments
-            )
-    ]
-};
+with 'Moose::Meta::Method::Accessor::Native::Reader';
 
 sub _minimum_arguments { 1 }
 
@@ -33,8 +19,11 @@ sub _inline_check_arguments {
 
     return (
         'if (!Params::Util::_CODELIKE($_[0])) {',
-            $self->_inline_throw_error(
-                '"The argument passed to first must be a code reference"',
+            $self->_inline_throw_exception( InvalidArgumentToMethod =>
+                                            'argument                => $_[0],'.
+                                            'method_name             => "first",'.
+                                            'type_of_argument        => "code reference",'.
+                                            'type                    => "CodeRef",',
             ) . ';',
         '}',
     );
