@@ -1,11 +1,5 @@
 package Moose::Meta::Method::Accessor::Native::Array::map;
-BEGIN {
-  $Moose::Meta::Method::Accessor::Native::Array::map::AUTHORITY = 'cpan:STEVAN';
-}
-{
-  $Moose::Meta::Method::Accessor::Native::Array::map::VERSION = '2.1005';
-}
-
+$Moose::Meta::Method::Accessor::Native::Array::map::VERSION = '2.1213';
 use strict;
 use warnings;
 
@@ -24,8 +18,11 @@ sub _inline_check_arguments {
 
     return (
         'if (!Params::Util::_CODELIKE($_[0])) {',
-            $self->_inline_throw_error(
-                '"The argument passed to map must be a code reference"',
+            $self->_inline_throw_exception( InvalidArgumentToMethod =>
+                                            'argument                => $_[0],'.
+                                            'method_name             => "map",'.
+                                            'type_of_argument        => "code reference",'.
+                                            'type                    => "CodeRef",',
             ) . ';',
         '}',
     );
