@@ -1,11 +1,5 @@
 package Moose::Meta::Method::Accessor::Native::Array::shuffle;
-BEGIN {
-  $Moose::Meta::Method::Accessor::Native::Array::shuffle::AUTHORITY = 'cpan:STEVAN';
-}
-{
-  $Moose::Meta::Method::Accessor::Native::Array::shuffle::VERSION = '2.0402';
-}
-
+$Moose::Meta::Method::Accessor::Native::Array::shuffle::VERSION = '2.1213';
 use strict;
 use warnings;
 
@@ -13,8 +7,7 @@ use List::Util ();
 
 use Moose::Role;
 
-with 'Moose::Meta::Method::Accessor::Native::Reader' =>
-    { -excludes => ['_maximum_arguments'] };
+with 'Moose::Meta::Method::Accessor::Native::Reader';
 
 sub _maximum_arguments { 0 }
 
