@@ -1,11 +1,5 @@
 package Moose::Meta::Method::Accessor::Native::Hash::kv;
-BEGIN {
-  $Moose::Meta::Method::Accessor::Native::Hash::kv::AUTHORITY = 'cpan:STEVAN';
-}
-{
-  $Moose::Meta::Method::Accessor::Native::Hash::kv::VERSION = '2.0401';
-}
-
+$Moose::Meta::Method::Accessor::Native::Hash::kv::VERSION = '2.1213';
 use strict;
 use warnings;
 
@@ -13,8 +7,7 @@ use Scalar::Util qw( looks_like_number );
 
 use Moose::Role;
 
-with 'Moose::Meta::Method::Accessor::Native::Reader' =>
-    { -excludes => ['_maximum_arguments'] };
+with 'Moose::Meta::Method::Accessor::Native::Reader';
 
 sub _maximum_arguments { 0 }
 
