@@ -1,24 +1,11 @@
 package Moose::Meta::Method::Accessor::Native::String::inc;
-BEGIN {
-  $Moose::Meta::Method::Accessor::Native::String::inc::AUTHORITY = 'cpan:STEVAN';
-}
-{
-  $Moose::Meta::Method::Accessor::Native::String::inc::VERSION = '2.0402';
-}
-
+$Moose::Meta::Method::Accessor::Native::String::inc::VERSION = '2.1213';
 use strict;
 use warnings;
 
 use Moose::Role;
 
-with 'Moose::Meta::Method::Accessor::Native::Writer' => {
-    -excludes => [
-        qw(
-            _maximum_arguments
-            _inline_optimized_set_new_value
-            )
-    ]
-    };
+with 'Moose::Meta::Method::Accessor::Native::Writer';
 
 sub _maximum_arguments { 0 }
 
