@@ -1,11 +1,5 @@
 package Moose::Meta::Method::Accessor::Native::String::match;
-BEGIN {
-  $Moose::Meta::Method::Accessor::Native::String::match::AUTHORITY = 'cpan:STEVAN';
-}
-{
-  $Moose::Meta::Method::Accessor::Native::String::match::VERSION = '2.1005';
-}
-
+$Moose::Meta::Method::Accessor::Native::String::match::VERSION = '2.1213';
 use strict;
 use warnings;
 
@@ -25,9 +19,11 @@ sub _inline_check_arguments {
 
     return (
         'if (!Moose::Util::_STRINGLIKE0($_[0]) && !Params::Util::_REGEX($_[0])) {',
-            $self->_inline_throw_error(
-                '"The argument passed to match must be a string or regexp '
-              . 'reference"',
+            $self->_inline_throw_exception( InvalidArgumentToMethod =>
+                                            'argument                => $_[0],'.
+                                            'type                    => "Str|RegexpRef",'.
+                                            'type_of_argument        => "string or regexp reference",'.
+                                            'method_name             => "match"',
             ) . ';',
         '}',
     );
