@@ -1,15 +1,11 @@
 package Moose::Meta::Method::Augmented;
-BEGIN {
-  $Moose::Meta::Method::Augmented::AUTHORITY = 'cpan:STEVAN';
-}
-{
-  $Moose::Meta::Method::Augmented::VERSION = '2.1005';
-}
-
+$Moose::Meta::Method::Augmented::VERSION = '2.1213';
 use strict;
 use warnings;
 
-use base 'Moose::Meta::Method';
+use parent 'Moose::Meta::Method';
+
+use Moose::Util 'throw_exception';
 
 sub new {
     my ( $class, %args ) = @_;
@@ -24,7 +20,10 @@ sub new {
     my $super = $meta->find_next_method_by_name($name);
 
     (defined $super)
-        || $meta->throw_error("You cannot augment '$name' because it has no super method", data => $name);
+        || throw_exception( CannotAugmentNoSuperMethod => params      => \%args,
+                                                          class       => $class,
+                                                          method_name => $name
+                          );
 
     my $_super_package = $super->package_name;
     # BUT!,... if this is an overridden method ....
@@ -64,13 +63,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Moose::Meta::Method::Augmented - A Moose Method metaclass for augmented methods
 
 =head1 VERSION
 
-version 2.1005
+version 2.1213
 
 =head1 DESCRIPTION
 
@@ -117,13 +118,55 @@ option is required.
 
 See L<Moose/BUGS> for details on reporting bugs.
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Moose is maintained by the Moose Cabal, along with the help of many contributors. See L<Moose/CABAL> and L<Moose/CONTRIBUTORS> for details.
+=over 4
+
+=item *
+
+Stevan Little <stevan.little@iinteractive.com>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=item *
+
+Jesse Luehrs <doy@tozt.net>
+
+=item *
+
+Shawn M Moore <code@sartak.org>
+
+=item *
+
+יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Florian Ragwitz <rafl@debian.org>
+
+=item *
+
+Hans Dieter Pearcey <hdp@weftsoar.net>
+
+=item *
+
+Chris Prather <chris@prather.org>
+
+=item *
+
+Matt S Trout <mst@shadowcat.co.uk>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Infinity Interactive, Inc..
+This software is copyright (c) 2006 by Infinity Interactive, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
