@@ -1,15 +1,9 @@
 package Moose::Meta::Mixin::AttributeCore;
-BEGIN {
-  $Moose::Meta::Mixin::AttributeCore::AUTHORITY = 'cpan:STEVAN';
-}
-{
-  $Moose::Meta::Mixin::AttributeCore::VERSION = '2.0402';
-}
-
+$Moose::Meta::Mixin::AttributeCore::VERSION = '2.1213';
 use strict;
 use warnings;
 
-use base 'Class::MOP::Mixin::AttributeCore';
+use parent 'Class::MOP::Mixin::AttributeCore';
 
 __PACKAGE__->meta->add_attribute(
     'isa' => (
@@ -110,17 +104,19 @@ __PACKAGE__->meta->add_attribute(
 
 # ABSTRACT: Core attributes shared by attribute metaclasses
 
-
+__END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Moose::Meta::Mixin::AttributeCore - Core attributes shared by attribute metaclasses
 
 =head1 VERSION
 
-version 2.0402
+version 2.1213
 
 =head1 DESCRIPTION
 
@@ -131,19 +127,57 @@ attributes. See the L<Moose::Meta::Attribute> documentation for API details.
 
 See L<Moose/BUGS> for details on reporting bugs.
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Moose is maintained by the Moose Cabal, along with the help of many contributors. See L<Moose/CABAL> and L<Moose/CONTRIBUTORS> for details.
+=over 4
+
+=item *
+
+Stevan Little <stevan.little@iinteractive.com>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=item *
+
+Jesse Luehrs <doy@tozt.net>
+
+=item *
+
+Shawn M Moore <code@sartak.org>
+
+=item *
+
+יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Florian Ragwitz <rafl@debian.org>
+
+=item *
+
+Hans Dieter Pearcey <hdp@weftsoar.net>
+
+=item *
+
+Chris Prather <chris@prather.org>
+
+=item *
+
+Matt S Trout <mst@shadowcat.co.uk>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Infinity Interactive, Inc..
+This software is copyright (c) 2006 by Infinity Interactive, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
