@@ -1,15 +1,11 @@
 package Moose::Meta::Role::Application;
-BEGIN {
-  $Moose::Meta::Role::Application::AUTHORITY = 'cpan:STEVAN';
-}
-{
-  $Moose::Meta::Role::Application::VERSION = '2.1005';
-}
-
+$Moose::Meta::Role::Application::VERSION = '2.1213';
 use strict;
 use warnings;
 use metaclass;
 
+use Moose::Util 'throw_exception';
+
 __PACKAGE__->meta->add_attribute('method_exclusions' => (
     init_arg => '-excludes',
     reader   => 'get_method_exclusions',
@@ -65,14 +61,14 @@ sub apply {
     $self->apply_after_method_modifiers(@_);
 }
 
-sub check_role_exclusions           { Carp::croak "Abstract Method" }
-sub check_required_methods          { Carp::croak "Abstract Method" }
-sub check_required_attributes       { Carp::croak "Abstract Method" }
+sub check_role_exclusions           { throw_exception( "CannotCallAnAbstractMethod" ); }
+sub check_required_methods          { throw_exception( "CannotCallAnAbstractMethod" ); }
+sub check_required_attributes       { throw_exception( "CannotCallAnAbstractMethod" ); }
 
-sub apply_attributes                { Carp::croak "Abstract Method" }
-sub apply_methods                   { Carp::croak "Abstract Method" }
-sub apply_override_method_modifiers { Carp::croak "Abstract Method" }
-sub apply_method_modifiers          { Carp::croak "Abstract Method" }
+sub apply_attributes                { throw_exception( "CannotCallAnAbstractMethod" ); }
+sub apply_methods                   { throw_exception( "CannotCallAnAbstractMethod" ); }
+sub apply_override_method_modifiers { throw_exception( "CannotCallAnAbstractMethod" ); }
+sub apply_method_modifiers          { throw_exception( "CannotCallAnAbstractMethod" ); }
 
 sub apply_before_method_modifiers   { (shift)->apply_method_modifiers('before' => @_) }
 sub apply_around_method_modifiers   { (shift)->apply_method_modifiers('around' => @_) }
@@ -86,13 +82,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Moose::Meta::Role::Application - A base class for role application
 
 =head1 VERSION
 
-version 2.1005
+version 2.1213
 
 =head1 DESCRIPTION
 
@@ -147,13 +145,55 @@ consideration, and is intentionally not yet documented.
 
 See L<Moose/BUGS> for details on reporting bugs.
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Moose is maintained by the Moose Cabal, along with the help of many contributors. See L<Moose/CABAL> and L<Moose/CONTRIBUTORS> for details.
+=over 4
+
+=item *
+
+Stevan Little <stevan.little@iinteractive.com>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=item *
+
+Jesse Luehrs <doy@tozt.net>
+
+=item *
+
+Shawn M Moore <code@sartak.org>
+
+=item *
+
+יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Florian Ragwitz <rafl@debian.org>
+
+=item *
+
+Hans Dieter Pearcey <hdp@weftsoar.net>
+
+=item *
+
+Chris Prather <chris@prather.org>
+
+=item *
+
+Matt S Trout <mst@shadowcat.co.uk>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Infinity Interactive, Inc..
+This software is copyright (c) 2006 by Infinity Interactive, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
