@@ -1,12 +1,5 @@
-
 package Moose::Meta::Role::Method::Required;
-BEGIN {
-  $Moose::Meta::Role::Method::Required::AUTHORITY = 'cpan:STEVAN';
-}
-{
-  $Moose::Meta::Role::Method::Required::VERSION = '2.1005';
-}
-
+$Moose::Meta::Role::Method::Required::VERSION = '2.1213';
 use strict;
 use warnings;
 use metaclass;
@@ -14,7 +7,7 @@ use metaclass;
 use overload '""'     => sub { shift->name },   # stringify to method name
              fallback => 1;
 
-use base qw(Class::MOP::Object);
+use parent 'Class::MOP::Object';
 
 # This is not a Moose::Meta::Role::Method because it has no implementation, it
 # is just a name
@@ -35,13 +28,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Moose::Meta::Role::Method::Required - A Moose metaclass for required methods in Roles
 
 =head1 VERSION
 
-version 2.1005
+version 2.1213
 
 =head1 DESCRIPTION
 
@@ -77,13 +72,55 @@ Returns the required method's name, as provided to the constructor.
 
 See L<Moose/BUGS> for details on reporting bugs.
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Moose is maintained by the Moose Cabal, along with the help of many contributors. See L<Moose/CABAL> and L<Moose/CONTRIBUTORS> for details.
+=over 4
+
+=item *
+
+Stevan Little <stevan.little@iinteractive.com>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=item *
+
+Jesse Luehrs <doy@tozt.net>
+
+=item *
+
+Shawn M Moore <code@sartak.org>
+
+=item *
+
+יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Florian Ragwitz <rafl@debian.org>
+
+=item *
+
+Hans Dieter Pearcey <hdp@weftsoar.net>
+
+=item *
+
+Chris Prather <chris@prather.org>
+
+=item *
+
+Matt S Trout <mst@shadowcat.co.uk>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Infinity Interactive, Inc..
+This software is copyright (c) 2006 by Infinity Interactive, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
