@@ -1,27 +1,23 @@
-
 package Moose::Meta::TypeCoercion::Union;
-BEGIN {
-  $Moose::Meta::TypeCoercion::Union::AUTHORITY = 'cpan:STEVAN';
-}
-{
-  $Moose::Meta::TypeCoercion::Union::VERSION = '2.1005';
-}
-
+$Moose::Meta::TypeCoercion::Union::VERSION = '2.1213';
 use strict;
 use warnings;
 use metaclass;
 
 use Scalar::Util 'blessed';
 
-use base 'Moose::Meta::TypeCoercion';
+use parent 'Moose::Meta::TypeCoercion';
+
+use Moose::Util 'throw_exception';
 
 sub compile_type_coercion {
     my $self            = shift;
     my $type_constraint = $self->type_constraint;
 
     (blessed $type_constraint && $type_constraint->isa('Moose::Meta::TypeConstraint::Union'))
-     || Moose->throw_error("You can only create a Moose::Meta::TypeCoercion::Union for a " .
-                "Moose::Meta::TypeConstraint::Union, not a $type_constraint");
+     || throw_exception( NeedsTypeConstraintUnionForTypeCoercionUnion => type_coercion_union_object => $self,
+                                                                         type_name                  => $type_constraint->name
+                       );
 
     $self->_compiled_type_coercion(
         sub {
@@ -41,8 +37,8 @@ sub compile_type_coercion {
 sub has_coercion_for_type { 0 }
 
 sub add_type_coercions {
-    require Moose;
-    Moose->throw_error("Cannot add additional type coercions to Union types");
+    my $self = shift;
+    throw_exception( CannotAddAdditionalTypeCoercionsToUnion => type_coercion_union_object => $self );
 }
 
 1;
@@ -53,18 +49,21 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Moose::Meta::TypeCoercion::Union - The Moose Type Coercion metaclass for Unions
 
 =head1 VERSION
 
-version 2.1005
+version 2.1213
 
 =head1 DESCRIPTION
 
 This is a subclass of L<Moose::Meta::TypeCoercion> that is used for
 L<Moose::Meta::TypeConstraint::Union> objects.
+
 =head1 METHODS
 
 =over 4
@@ -89,13 +88,55 @@ union.
 
 See L<Moose/BUGS> for details on reporting bugs.
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Moose is maintained by the Moose Cabal, along with the help of many contributors. See L<Moose/CABAL> and L<Moose/CONTRIBUTORS> for details.
+=over 4
+
+=item *
+
+Stevan Little <stevan.little@iinteractive.com>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=item *
+
+Jesse Luehrs <doy@tozt.net>
+
+=item *
+
+Shawn M Moore <code@sartak.org>
+
+=item *
+
+יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Florian Ragwitz <rafl@debian.org>
+
+=item *
+
+Hans Dieter Pearcey <hdp@weftsoar.net>
+
+=item *
+
+Chris Prather <chris@prather.org>
+
+=item *
+
+Matt S Trout <mst@shadowcat.co.uk>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Infinity Interactive, Inc..
+This software is copyright (c) 2006 by Infinity Interactive, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
