@@ -1,28 +1,23 @@
-package Moose::Role;
-BEGIN {
-  $Moose::Role::AUTHORITY = 'cpan:STEVAN';
-}
-{
-  $Moose::Role::VERSION = '2.1005';
-}
 use strict;
 use warnings;
-
+package Moose::Role;
+$Moose::Role::VERSION = '2.1213';
 use Scalar::Util 'blessed';
 use Carp         'croak';
 use Class::Load  'is_class_loaded';
+use Module::Runtime 'module_notional_filename';
 
 use Sub::Exporter;
 
 use Moose       ();
-use Moose::Util ();
+use Moose::Util 'throw_exception';
 
 use Moose::Exporter;
 use Moose::Meta::Role;
 use Moose::Util::TypeConstraints;
 
 sub extends {
-    croak "Roles do not support 'extends' (you can use 'with' to specialize a role)";
+    throw_exception("RolesDoNotSupportExtends");
 }
 
 sub with {
@@ -31,20 +26,23 @@ sub with {
 
 sub requires {
     my $meta = shift;
-    croak "Must specify at least one method" unless @_;
+    throw_exception( MustSpecifyAtleastOneMethod => role_name => $meta->name ) unless @_;
     $meta->add_required_methods(@_);
 }
 
 sub excludes {
     my $meta = shift;
-    croak "Must specify at least one role" unless @_;
+    throw_exception( MustSpecifyAtleastOneRole => role_name => $meta->name ) unless @_;
     $meta->add_excluded_roles(@_);
 }
 
 sub has {
     my $meta = shift;
     my $name = shift;
-    croak 'Usage: has \'name\' => ( key => value, ... )' if @_ == 1;
+    throw_exception( InvalidHasProvidedInARole => role_name       => $meta->name,
+                                                  attribute_name  => $name,
+                   )
+        if @_ == 1;
     my %context = Moose::Util::_caller_info;
     $context{context} = 'has declaration';
     $context{type} = 'role';
@@ -58,8 +56,9 @@ sub _add_method_modifier {
     my $meta = shift;
 
     if ( ref($_[0]) eq 'Regexp' ) {
-        croak "Roles do not currently support regex "
-            . " references for $type method modifiers";
+        throw_exception( RolesDoNotSupportRegexReferencesForMethodModifiers => modifier_type => $type,
+                                                                               role_name     => $meta->name,
+                       );
     }
 
     Moose::Util::add_method_modifier($meta, $type, \@_);
@@ -84,11 +83,11 @@ sub override {
 }
 
 sub inner {
-    croak "Roles cannot support 'inner'";
+    throw_exception("RolesDoNotSupportInner");
 }
 
 sub augment {
-    croak "Roles cannot support 'augment'";
+    throw_exception("RolesDoNotSupportAugment");
 }
 
 Moose::Exporter->setup_import_methods(
@@ -110,16 +109,16 @@ sub init_meta {
 
     unless ($role) {
         require Moose;
-        Moose->throw_error("Cannot call init_meta without specifying a for_class");
+        throw_exception( InitMetaRequiresClass => params => \%args );
     }
 
     my $metaclass = $args{metaclass} || "Moose::Meta::Role";
     my $meta_name = exists $args{meta_name} ? $args{meta_name} : 'meta';
 
-    Moose->throw_error("The Metaclass $metaclass must be loaded. (Perhaps you forgot to 'use $metaclass'?)")
+    throw_exception( MetaclassNotLoaded => class_name => $metaclass )
         unless is_class_loaded($metaclass);
 
-    Moose->throw_error("The Metaclass $metaclass must be a subclass of Moose::Meta::Role.")
+    throw_exception( MetaclassMustBeASubclassOfMooseMetaRole => role_name => $metaclass )
         unless $metaclass->isa('Moose::Meta::Role');
 
     # make a subtype for each Moose role
@@ -128,16 +127,22 @@ sub init_meta {
     my $meta;
     if ( $meta = Class::MOP::get_metaclass_by_name($role) ) {
         unless ( $meta->isa("Moose::Meta::Role") ) {
-            my $error_message = "$role already has a metaclass, but it does not inherit $metaclass ($meta).";
             if ( $meta->isa('Moose::Meta::Class') ) {
-                Moose->throw_error($error_message . ' You cannot make the same thing a role and a class. Remove either Moose or Moose::Role.');
+                throw_exception( MetaclassIsAClassNotASubclassOfGivenMetaclass => class_name => $role,
+                                                                                  metaclass  => $metaclass,
+                               );
             } else {
-                Moose->throw_error($error_message);
+                throw_exception( MetaclassIsNotASubclassOfGivenMetaclass => class_name => $role,
+                                                                            metaclass  => $metaclass,
+                               );
             }
         }
     }
     else {
         $meta = $metaclass->initialize($role);
+        my $filename = module_notional_filename($meta->name);
+        $INC{$filename} = '(set by Moose)'
+            unless exists $INC{$filename};
     }
 
     if (defined $meta_name) {
@@ -166,13 +171,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Moose::Role - The Moose Role
 
 =head1 VERSION
 
-version 2.1005
+version 2.1213
 
 =head1 SYNOPSIS
 
@@ -264,6 +271,9 @@ this, your class's C<meta> object will have the specified traits
 applied to it. See L<Moose/Metaclass and Trait Name Resolution> for more
 details.
 
+All role metaclasses (note, not the role itself) extend L<Moose::Meta::Role>.
+You can test if a package is a role or not using L<Moose::Util/is_role>.
+
 =head1 APPLYING ROLES
 
 In addition to being applied to a class using the 'with' syntax (see
@@ -314,13 +324,55 @@ ordering.
 
 See L<Moose/BUGS> for details on reporting bugs.
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Moose is maintained by the Moose Cabal, along with the help of many contributors. See L<Moose/CABAL> and L<Moose/CONTRIBUTORS> for details.
+=over 4
+
+=item *
+
+Stevan Little <stevan.little@iinteractive.com>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=item *
+
+Jesse Luehrs <doy@tozt.net>
+
+=item *
+
+Shawn M Moore <code@sartak.org>
+
+=item *
+
+יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Florian Ragwitz <rafl@debian.org>
+
+=item *
+
+Hans Dieter Pearcey <hdp@weftsoar.net>
+
+=item *
+
+Chris Prather <chris@prather.org>
+
+=item *
+
+Matt S Trout <mst@shadowcat.co.uk>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Infinity Interactive, Inc..
+This software is copyright (c) 2006 by Infinity Interactive, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
