@@ -1,15 +1,9 @@
 package Moose::Util;
-BEGIN {
-  $Moose::Util::AUTHORITY = 'cpan:STEVAN';
-}
-{
-  $Moose::Util::VERSION = '2.1005';
-}
-
+$Moose::Util::VERSION = '2.1213';
 use strict;
 use warnings;
 
-use Class::Load 0.07 qw(load_class load_first_existing_class);
+use Module::Runtime 0.014 'use_package_optimistically', 'use_module', 'module_notional_filename';
 use Data::OptList;
 use Params::Util qw( _STRING );
 use Sub::Exporter;
@@ -18,10 +12,11 @@ use List::Util qw(first);
 use List::MoreUtils qw(any all);
 use overload ();
 use Try::Tiny;
-use Class::MOP;
+
 
 my @exports = qw[
     find_meta
+    is_role
     does_role
     search_class_by_role
     ensure_all_roles
@@ -35,6 +30,7 @@ my @exports = qw[
     english_list
     meta_attribute_alias
     meta_class_alias
+    throw_exception
 ];
 
 Sub::Exporter::setup_exporter({
@@ -42,12 +38,31 @@ Sub::Exporter::setup_exporter({
     groups  => { all => \@exports }
 });
 
+# Things that need to ->import from Moose::Util
+# should be loaded after Moose::Util defines ->import
+require Class::MOP;
+
+sub throw_exception {
+    my ($class_name, @args_to_exception) = @_;
+    my $class = "Moose::Exception::$class_name";
+    _load_user_class( $class );
+    die $class->new( @args_to_exception );
+}
+
 ## some utils for the utils ...
 
 sub find_meta { Class::MOP::class_of(@_) }
 
 ## the functions ...
 
+sub is_role {
+    my $package_or_obj = shift;
+
+    my $meta = find_meta($package_or_obj);
+    return if not $meta;
+    return $meta->isa('Moose::Meta::Role');
+}
+
 sub does_role {
     my ($class_or_obj, $role) = @_;
 
@@ -105,7 +120,7 @@ sub _apply_all_roles {
 
     unless (@_) {
         require Moose;
-        Moose->throw_error("Must specify at least one role to apply to $applicant");
+        throw_exception( MustSpecifyAtleastOneRoleToApplicant => applicant => $applicant );
     }
 
     # If @_ contains role meta objects, mkopt will think that they're values,
@@ -129,15 +144,12 @@ sub _apply_all_roles {
             $meta = $role->[0];
         }
         else {
-            load_class( $role->[0] , $role->[1] );
+            &use_module($role->[0], $role->[1] && $role->[1]{-version} ? $role->[1]{-version} : ());
             $meta = find_meta( $role->[0] );
         }
 
         unless ($meta && $meta->isa('Moose::Meta::Role') ) {
-            require Moose;
-            Moose->throw_error( "You can only consume roles, "
-                    . $role->[0]
-                    . " is not a Moose role" );
+            throw_exception( CanOnlyConsumeRole => role_name => $role->[0] );
         }
 
         push @role_metas, [ $meta, $role->[1] ];
@@ -149,7 +161,7 @@ sub _apply_all_roles {
 
     return unless @role_metas;
 
-    load_class($applicant)
+    _load_user_class($applicant)
         unless blessed($applicant)
             || Class::MOP::class_of($applicant);
 
@@ -222,15 +234,24 @@ sub _build_alias_package_name {
             $type, $metaclass_name, $options{trait}
         );
 
-        my $loaded_class = load_first_existing_class(
-            $possible_full_name,
-            $metaclass_name
-        );
+        my @possible = ($possible_full_name, $metaclass_name);
+        for my $package (@possible) {
+            use_package_optimistically($package);
+            if ($package->can('register_implementation')) {
+                return $cache{$cache_key}{$metaclass_name} =
+                    $package->register_implementation;
+            }
+            elsif (find_meta($package)) {
+                return $cache{$cache_key}{$metaclass_name} = $package;
+            }
+        }
 
-        return $cache{$cache_key}{$metaclass_name}
-            = $loaded_class->can('register_implementation')
-            ? $loaded_class->register_implementation
-            : $loaded_class;
+        throw_exception( CannotLocatePackageInINC => possible_packages => _english_list_or(@possible),
+                                                     INC               => \@INC,
+                                                     type              => $type,
+                                                     metaclass_name    => $metaclass_name,
+                                                     params            => \%options
+                       );
     }
 }
 
@@ -254,13 +275,10 @@ sub add_method_modifier {
             $meta->$add_modifier_method( $_, $code ) for @{$args->[0]};
         }
         else {
-            $meta->throw_error(
-                sprintf(
-                    "Methods passed to %s must be provided as a list, arrayref or regex, not %s",
-                    $modifier_name,
-                    $method_modifier_type,
-                )
-            );
+            throw_exception( IllegalMethodTypeToAddMethodModifier => class_or_object => $class_or_obj,
+                                                                     modifier_name   => $modifier_name,
+                                                                     params          => $args
+                           );
         }
     }
     else {
@@ -269,14 +287,28 @@ sub add_method_modifier {
 }
 
 sub english_list {
-    my @items = sort @_;
+    _english_list_and(@_);
+}
+
+sub _english_list_and {
+    _english_list('and', \@_);
+}
+
+sub _english_list_or {
+    _english_list('or', \@_);
+}
+
+sub _english_list {
+    my ($conjunction, $items) = @_;
+
+    my @items = sort @$items;
 
     return $items[0] if @items == 1;
-    return "$items[0] and $items[1]" if @items == 2;
+    return "$items[0] $conjunction $items[1]" if @items == 2;
 
     my $tail = pop @items;
     my $list = join ', ', @items;
-    $list .= ', and ' . $tail;
+    $list .= ", $conjunction " . $tail;
 
     return $list;
 }
@@ -312,6 +344,14 @@ sub meta_class_alias {
     _create_alias('Class', $to, $trait, $from);
 }
 
+sub _load_user_class {
+    my ($class, $opts) = @_;
+    &use_package_optimistically(
+        $class,
+        $opts && $opts->{-version} ? $opts->{-version} : ()
+    );
+}
+
 # XXX - this should be added to Params::Util
 sub _STRINGLIKE0 ($) {
     return 1 if _STRING( $_[0] );
@@ -480,6 +520,11 @@ sub _is_role_only_subclass {
     return 1;
 }
 
+sub _is_package_loaded {
+    my ($package) = @_;
+    defined $INC{module_notional_filename($package)};
+}
+
 1;
 
 # ABSTRACT: Utilities for working with Moose classes
@@ -488,13 +533,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Moose::Util - Utilities for working with Moose classes
 
 =head1 VERSION
 
-version 2.1005
+version 2.1213
 
 =head1 SYNOPSIS
 
@@ -525,6 +572,10 @@ This method takes a class name or object and attempts to find a
 metaclass for the class, if one exists. It will B<not> create one if it
 does not yet exist.
 
+=item B<is_role($package_or_obj)>
+
+Returns true if the provided package name or object is a L<Moose::Role>.
+
 =item B<does_role($class_or_obj, $role_or_obj)>
 
 Returns true if C<$class_or_obj> does the given C<$role_or_obj>. The role can
@@ -604,6 +655,11 @@ Given a list of scalars, turns them into a proper list in English
 ("one and two", "one, two, three, and four"). This is used to help us
 make nicer error messages.
 
+=item B<throw_exception( $class_name, %arguments_to_exception)>
+
+Calls die with an object of Moose::Exception::$class_name, with
+%arguments_to_exception passed as arguments.
+
 =back
 
 =head1 TODO
@@ -622,13 +678,55 @@ Here is a list of possible functions to write
 
 See L<Moose/BUGS> for details on reporting bugs.
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Moose is maintained by the Moose Cabal, along with the help of many contributors. See L<Moose/CABAL> and L<Moose/CONTRIBUTORS> for details.
+=over 4
+
+=item *
+
+Stevan Little <stevan.little@iinteractive.com>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=item *
+
+Jesse Luehrs <doy@tozt.net>
+
+=item *
+
+Shawn M Moore <code@sartak.org>
+
+=item *
+
+יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Florian Ragwitz <rafl@debian.org>
+
+=item *
+
+Hans Dieter Pearcey <hdp@weftsoar.net>
+
+=item *
+
+Chris Prather <chris@prather.org>
+
+=item *
+
+Matt S Trout <mst@shadowcat.co.uk>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Infinity Interactive, Inc..
+This software is copyright (c) 2006 by Infinity Interactive, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
