@@ -1,21 +1,16 @@
 package Moose::Util::MetaRole;
-BEGIN {
-  $Moose::Util::MetaRole::AUTHORITY = 'cpan:STEVAN';
-}
-{
-  $Moose::Util::MetaRole::VERSION = '2.1005';
-}
-
+$Moose::Util::MetaRole::VERSION = '2.1213';
 use strict;
 use warnings;
 use Scalar::Util 'blessed';
 
-use Carp qw( croak );
 use List::MoreUtils qw( all );
 use List::Util qw( first );
 use Moose::Deprecated;
 use Scalar::Util qw( blessed );
 
+use Moose::Util 'throw_exception';
+
 sub apply_metaroles {
     my %args = @_;
 
@@ -45,28 +40,7 @@ sub _metathing_for {
 
     local $Carp::CarpLevel = $Carp::CarpLevel + 1;
 
-    my $error_start
-        = 'When using Moose::Util::MetaRole, you must pass a Moose class name,'
-        . ' role name, metaclass object, or metarole object.';
-
-    if ( defined $found && blessed $found ) {
-        croak $error_start
-            . " You passed $passed, and we resolved this to a "
-            . ( blessed $found )
-            . ' object.';
-    }
-
-    if ( defined $passed && !defined $found ) {
-        croak $error_start
-            . " You passed $passed, and this did not resolve to a metaclass or metarole."
-            . ' Maybe you need to call Moose->init_meta to initialize the metaclass first?';
-    }
-
-    if ( !defined $passed ) {
-        croak $error_start
-            . " You passed an undef."
-            . ' Maybe you need to call Moose->init_meta to initialize the metaclass first?';
-    }
+    throw_exception( InvalidArgPassedToMooseUtilMetaRole => argument => $passed );
 }
 
 sub _make_new_metaclass {
@@ -105,7 +79,9 @@ sub apply_base_class_roles {
     my %args = @_;
 
     my $meta = _metathing_for( $args{for} || $args{for_class} );
-    croak 'You can only apply base class roles to a Moose class, not a role.'
+    throw_exception( CannotApplyBaseClassRolesToRole => params    => \%args,
+                                                        role_name => $meta->name,
+                   )
         if $meta->isa('Moose::Meta::Role');
 
     my $new_base = _make_new_class(
@@ -146,13 +122,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Moose::Util::MetaRole - Apply roles to any metaclass, as well as the object base class
 
 =head1 VERSION
 
-version 2.1005
+version 2.1213
 
 =head1 SYNOPSIS
 
@@ -177,7 +155,7 @@ version 2.1005
       Moose::Util::MetaRole::apply_metaroles(
           for             => $args{for_class},
           class_metaroles => {
-              class => => ['MyApp::Role::Meta::Class'],
+              class       => ['MyApp::Role::Meta::Class'],
               constructor => ['MyApp::Role::Meta::Method::Constructor'],
           },
       );
@@ -297,13 +275,55 @@ This function will apply the specified roles to the object's base class.
 
 See L<Moose/BUGS> for details on reporting bugs.
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Moose is maintained by the Moose Cabal, along with the help of many contributors. See L<Moose/CABAL> and L<Moose/CONTRIBUTORS> for details.
+=over 4
+
+=item *
+
+Stevan Little <stevan.little@iinteractive.com>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=item *
+
+Jesse Luehrs <doy@tozt.net>
+
+=item *
+
+Shawn M Moore <code@sartak.org>
+
+=item *
+
+יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Florian Ragwitz <rafl@debian.org>
+
+=item *
+
+Hans Dieter Pearcey <hdp@weftsoar.net>
+
+=item *
+
+Chris Prather <chris@prather.org>
+
+=item *
+
+Matt S Trout <mst@shadowcat.co.uk>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Infinity Interactive, Inc..
+This software is copyright (c) 2006 by Infinity Interactive, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
